@@ -19,7 +19,9 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import commands, os, time
+import commands, os, time, logging
+
+logger = logging.getLogger("testdrive.virt.vbox")
 
 class VBox:
 
@@ -49,11 +51,9 @@ class VBox:
         self.vboxversion = commands.getoutput("VBoxManage --version")
         self.vboxversion = ( int(self.vboxversion.split(".")[0]), int(self.vboxversion.split(".")[1]) )
         if self.vboxversion == (3,1) or self.vboxversion == (3,2) or self.vboxversion == (4,0) or self.vboxversion == (4,1) or self.vboxversion == (4,2):
-            #info("VirtualBox %s detected." % self.vboxversion)
-            print "INFO: VirtualBox %s.%s detected." % self.vboxversion
+            logger.info("VirtualBox %s.%s detected." % self.vboxversion)
         else:
-            #error("Unsupported version (%s) of VirtualBox; please install v3.0 or v3.1." % self.vboxversion)
-            print "ERROR: Unsupported version (%s.%s) of VirtualBox; please install v3.1, v3.2, v4.0 or v4.1." % self.vboxversion
+            logger.error("ERROR: Unsupported version (%s.%s) of VirtualBox; please install v3.1, v3.2, v4.0 or v4.1." % self.vboxversion)
             exit(0)
 
     # Code to setup virtual machine
@@ -63,15 +63,14 @@ class VBox:
             os.unlink(self.DISK_FILE)
         if not os.path.exists(self.DISK_FILE):
             self.DISK_SIZE = self.DISK_SIZE.replace("G", "000")
-            #info("Creating disk image...")
-            print "INFO: Creating disk image..."
+            logger.info("Creating disk image...")
             self.run_or_die("VBoxManage createhd --filename %s --size %s" % (self.DISK_FILE, self.DISK_SIZE))
         if self.vboxversion == (3,1) or self.vboxversion == (3,2) or self.vboxversion == (4,0) or self.vboxversion == (4,1) or self.vboxversion == (4,2):
             self.run("VBoxManage storageattach %s --storagectl \"IDE Controller\" --port 0 --device 0 --type hdd --medium none" % self.VBOX_NAME)
             if self.PATH_TO_ISO != "/dev/null":
                 self.run("VBoxManage storageattach %s --storagectl \"IDE Controller\" --port 0 --device 1 --type dvddrive --medium none" % self.VBOX_NAME)
         #info("Creating the Virtual Machine...")
-        print "INFO: Creating the Virtual Machine..."
+        logger.info("Creating the Virtual Machine...")
         if os.path.exists("%s/.VirtualBox/Machines/%s/%s.xml" % (self.HOME, self.VBOX_NAME, self.VBOX_NAME)):
             os.unlink("%s/.VirtualBox/Machines/%s/%s.xml" % (self.HOME, self.VBOX_NAME, self.VBOX_NAME))
         self.run("VBoxManage unregistervm %s --delete" % self.VBOX_NAME)
@@ -90,8 +89,7 @@ class VBox:
 
     # Code launch virtual machine
     def launch_virt(self):
-        #info("Running the Virtual Machine...")
-        print "Running the Virtual Machine..."
+        logger.info("Running the Virtual Machine...")
         if self.vboxversion == (3,1) or self.vboxversion == (3,2) or self.vboxversion == (4,0) or self.vboxversion == (4,1) or self.vboxversion == (4,2):
             self.run_or_die("VBoxManage storagectl %s --name \"IDE Controller\" --add ide" % self.VBOX_NAME)
             self.run_or_die("VBoxManage storageattach %s --storagectl \"IDE Controller\" --port 0 --device 0 --type hdd --medium %s" % (self.VBOX_NAME, self.DISK_FILE))
@@ -111,5 +109,4 @@ class VBox:
 
     def run_or_die(self, cmd):
         if self.run(cmd) != 0:
-            #error("Command failed\n    `%s`" % cmd)
-            print "Command failed\n    `%s`" % cmd
+            logger.error("Command failed\n    `%s`" % cmd)
